@@ -1,6 +1,6 @@
 from .stack import Stack
 from .utils import change
-from .utils.node import Node
+from .utils.node import Node, equals as node_equals
 
 
 class Queue(object):
@@ -97,6 +97,9 @@ class Queue(object):
         for i in range(n):
             self.enqueue(self.dequeue())
 
+    def equals(self, queue):
+        return node_equals(self.__front, queue.__front)
+
     @classmethod
     def merge(cls, q1, q2):
         try:
