@@ -27,3 +27,12 @@ class Node:
     @prev.setter
     def prev(self, ptr):
         self.__prev = ptr
+
+
+def equals(node1, node2):
+    if node1 is None and node2 is None:
+        return True
+    elif node1 is None or node2 is None:
+        return False
+    else:
+        return (node1.data == node2.data) and equals(node1.next, node2.next) and equals(node1.prev, node2.prev)
