@@ -39,3 +39,12 @@ class Pair:
         pair.__first = first
         pair.__second = second
         return pair
+
+
+def equals(pair1, pair2):
+    if pair1 is None and pair2 is None:
+        return True
+    elif pair1 is None or pair2 is None:
+        return False
+    else:
+        return pair1.second == pair2.second
