@@ -1,4 +1,3 @@
-
 class Node:
     def __init__(self, data=None, left=None, right=None):
         self.__data = data
@@ -45,3 +44,12 @@ class Node:
                 cur.right = node
             else:
                 cls.chain(cur.right, node)
+
+
+def equals(bst1, bst2):
+    if bst1 is None and bst2 is None:
+        return True
+    elif bst1 is None or bst2 is None:
+        return False
+    else:
+        return (bst1.data == bst2.data) and equals(bst1.right, bst2.right) and equals(bst1.left, bst2.left)
